==> ejc-supbid-impl-3.0.1-20211123.065831-3-sources.jar: com/ejianc/business/supbid/material/bean/SchemeEntity.java <==
package com.ejianc.business.supbid.material.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.supbid.material.bean.SchemeDetailEntity;
/**
 * 方案实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_material_scheme")
public class SchemeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="notice_id")
    private java.lang.Long noticeId; // 主表主键
    @TableField(value="source_id")
    private java.lang.String sourceId; // 招标信息主键
    @TableField(value="scheme_name")
    private java.lang.String schemeName; // 方案名称
    @TableField(value="money")
    private java.math.BigDecimal money; // 报价总额
    @TableField(value="money_tax")
    private java.math.BigDecimal moneyTax; // 报价总额(含税)
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="schemeDetailService",pidName = "schemeId")
    private List<SchemeDetailEntity> schemeDetailEntities = new ArrayList<>(); // 报价明细实体
    

    /**
     * 主表主键
     */
    public java.lang.Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(java.lang.Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }

    public String getSchemeName() {
        return schemeName;
    }

    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }

    /**
     * 报价总额
     */
    public java.math.BigDecimal getMoney() {
        return money;
    }

    /**
     * 报价总额
     */
    public void setMoney(java.math.BigDecimal money) {
        this.money = money;
    }
    /**
     * 报价总额(含税)
     */
    public java.math.BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 报价总额(含税)
     */
    public void setMoneyTax(java.math.BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    
    /**
     * 报价明细实体
     */
    public List<SchemeDetailEntity> getSchemeDetailEntities() {
        return schemeDetailEntities;
    }

    /**
     * 报价明细实体
     */
    public void setSchemeDetailEntities(List<SchemeDetailEntity> schemeDetailEntities) {
        this.schemeDetailEntities = schemeDetailEntities;
    }
}

==> ejc-supbid-impl-3.0.1-20211125.113231-21-sources.jar: com/ejianc/business/supbid/material/bean/SchemeEntity.java <==
package com.ejianc.business.supbid.material.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.supbid.material.bean.SchemeDetailEntity;
/**
 * 方案实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_material_scheme")
public class SchemeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="notice_id")
    private java.lang.Long noticeId; // 主表主键
    @TableField(value="source_id")
    private java.lang.String sourceId; // 招标信息主键
    @TableField(value="scheme_name")
    private java.lang.String schemeName; // 方案名称
    @TableField(value="money")
    private java.math.BigDecimal money; // 报价总额
    @TableField(value="money_tax")
    private java.math.BigDecimal moneyTax; // 报价总额(含税)
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="schemeDetailService",pidName = "schemeId")
    private List<SchemeDetailEntity> schemeDetailList = new ArrayList<>(); // 报价明细实体
    

    /**
     * 主表主键
     */
    public java.lang.Long getNoticeId() {
        return noticeId;
    }

    /**
     * 主表主键
     */
    public void setNoticeId(java.lang.Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }

    public String getSchemeName() {
        return schemeName;
    }

    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }

    /**
     * 报价总额
     */
    public java.math.BigDecimal getMoney() {
        return money;
    }

    /**
     * 报价总额
     */
    public void setMoney(java.math.BigDecimal money) {
        this.money = money;
    }
    /**
     * 报价总额(含税)
     */
    public java.math.BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 报价总额(含税)
     */
    public void setMoneyTax(java.math.BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    
    /**
     * 报价明细实体
     */
    public List<SchemeDetailEntity> getSchemeDetailList() {
        return schemeDetailList;
    }

    public void setSchemeDetailList(List<SchemeDetailEntity> schemeDetailList) {
        this.schemeDetailList = schemeDetailList;
    }
}
